# Try to find the Qt binding of the Tapioca library
# TAPIOCA_QT_FOUND - system has Tapioca-Qt
# TAPIOCA_QT_INCLUDE_DIR - the Tapioca-Qt include directory
# TAPIOCA_QT_LIBRARIES - Link these to use Tapioca-Qt

# Copyright (c) 2008, Allen Winter <winter@kde.org>
#
# Redistribution and use is allowed according to the terms of the BSD license.
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.

SET (TAPIOCA_QT_FIND_REQUIRED ${TapiocaQt_FIND_REQUIRED})
if (TAPIOCA_QT_INCLUDE_DIR AND TAPIOCA_QT_LIBRARIES)
  # Already in cache, be silent
  set(TAPIOCA_QT_FIND_QUIETLY TRUE)
endif (TAPIOCA_QT_INCLUDE_DIR AND TAPIOCA_QT_LIBRARIES)

# Are we using this inside kdesupport ?
# Then expect that QtTapioca is also part of kdesupport:
if(KDESupport_SOURCE_DIR)
   set(TAPIOCA_QT_INCLUDE_DIR ${KDESupport_SOURCE_DIR}/tapioca-qt/include)
   set(TAPIOCA_QT_LIBRARIES QtTapioca)
else(KDESupport_SOURCE_DIR)
   # otherwise try to find it just like any other project:
   find_path(TAPIOCA_QT_INCLUDE_DIR
          NAMES QtTapioca/Channel QtTapioca/Connection
          PATHS ${CMAKE_INSTALL_PREFIX}/include
   )
   find_library(TAPIOCA_QT_LIBRARIES
             NAMES QtTapioca
             PATHS ${CMAKE_INSTALL_PREFIX}/lib
   )
endif(KDESupport_SOURCE_DIR)

include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(TAPIOCA_QT DEFAULT_MSG
                                  TAPIOCA_QT_LIBRARIES TAPIOCA_QT_INCLUDE_DIR)


mark_as_advanced(TAPIOCA_QT_INCLUDE_DIR TAPIOCA_QT_LIBRARIES)

